@@ -3,7 +3,7 @@
 import codecs
 import cssutils
 
-cssText = codecs.open('sheets/cases.css', encoding='css').read()
+cssText = codecs.open('../sheets/cases.css', encoding='css').read()
 sheet = cssutils.parseString(cssText)
 print sheet
 print sheet.cssText
\ No newline at end of file
