@@ -245,14 +245,20 @@ class CSSStyleSheet(cssutils.stylesheets.StyleSheet):
             if rule.wellformed:
                 self.insertRule(rule)
             return 3
-
+        
         def unknownrule(expected, seq, token, tokenizer):
             # parse and consume tokens in any case
-            self._log.warn(u'CSSStylesheet: Unknown @rule found.',
-                           token, neverraise=True)
-            rule = cssutils.css.CSSUnknownRule(self._tokensupto2(tokenizer,
-                                                                 token),
-                                               parentStyleSheet=self)
+            if token[1] in cssutils.css.MarginRule.margins:
+                self._log.error(u'CSSStylesheet: MarginRule out CSSPageRule.',
+                                token, neverraise=True)
+                rule = cssutils.css.MarginRule(parentStyleSheet=self)
+                rule.cssText = self._tokensupto2(tokenizer, token)
+            else:
+                self._log.warn(u'CSSStylesheet: Unknown @rule found.',
+                               token, neverraise=True)
+                rule = cssutils.css.CSSUnknownRule(parentStyleSheet=self)
+                rule.cssText = self._tokensupto2(tokenizer, token)
+                
             if rule.wellformed:
                 self.insertRule(rule)
 
@@ -779,6 +785,17 @@ class CSSStyleSheet(cssutils.stylesheets.StyleSheet):
                          doc=u'A ref to an @import rule if it is imported, '
                              u'else ``None``.')
 
+    def _getValid(self):
+        """Check if each contained rule is valid."""
+        for rule in self.cssRules:
+            # Not all rules can be checked for validity
+            if hasattr(rule, 'valid') and not rule.valid:
+                return False
+        return True
+
+    valid = property(_getValid,
+                     doc=u'``True`` if all contained rules are valid')
+
 
     @Deprecated(u'Use ``cssutils.setSerializer(serializer)`` instead.')
     def setSerializer(self, cssserializer):
