@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-"""Combine sheets referred to by @import rules in a given CSS proxy sheet
+"""Combine all sheets referred to a given CSS *proxy* sheet
 into a single new sheet.
 
-- proxy currently is a path (no URI!)
+- no ``url()`` values are adjusted so currently when using relative references
+  for e.g. images it is best to have all sheets in a single folder 
 - in @import rules only relative paths do work for now but should be used
   anyway
-- currently no nested @imports are resolved
 - messages are send to stderr
 - output to stdout.
 
@@ -49,23 +49,21 @@ or without option -m::
         top: 3px
         }
 
-TODO
-    - URL or file hrefs? URI should be default
-    - no nested @imports are resolved yet
-    - maybe add a config file which is used?
-
 """
 __all__ = ['csscombine']
 __docformat__ = 'restructuredtext'
-__version__ = '$Id: csscombine.py 1332 2008-07-09 13:12:56Z cthedot $'
+__version__ = '$Id$'
 
+from cssutils.script import csscombine
 import optparse
 import sys
-from cssutils.script import csscombine
 
 def main(args=None):
-    usage = "usage: %prog [options] path"
+    usage = "usage: %prog [options] [path]"
     parser = optparse.OptionParser(usage=usage)
+    parser.add_option('-u', '--url', action='store',
+        dest='url', 
+        help='URL to parse (path is ignored if URL given)')
     parser.add_option('-s', '--sourceencoding', action='store',
         dest='sourceencoding', 
         help='encoding of input, defaulting to "css". If given overwrites other encoding information like @charset declarations')
@@ -77,13 +75,19 @@ def main(args=None):
         help='saves minified version of combined files, defaults to False')
     options, path = parser.parse_args()
 
-    if not path:
-        parser.error('no path given')
+    if options.url:
+        print csscombine(url=options.url,
+                         sourceencoding=options.sourceencoding, 
+                         targetencoding=options.targetencoding,
+                         minify=options.minify)
+    elif path:
+        print csscombine(path=path[0],
+                         sourceencoding=options.sourceencoding, 
+                         targetencoding=options.targetencoding,
+                         minify=options.minify)
     else:
-        path = path[0]
+        parser.error('no path or URL (-u) given')
 
-    print csscombine(path, options.sourceencoding, options.targetencoding,
-                     options.minify)
 
 
 if __name__ == '__main__':
